#   *******************************************************************
#   * Licensed Materials - Property of IBM
#   * Tivoli Common Agent
#   * BTCJ
#   * Copyright IBM Corp. 2010. All Rights Reserved
#   *
#   * US Government Users Restricted Rights - Use, duplication or
#   * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#   *******************************************************************
#
#  This script will install the man page file
INSTALL=1
UNINSTALL=0

#Checking for Errors in the last executed command
# $1	- return code of the last command execution
# $2	- Error message
checkError()
{
	if [ $1 -ne 0 ]; then
		echo $2
		echo
		exit $1
	fi
}

if [[ $# -ne 2 ]]; then
	echo
	CMD=`echo $0 | awk -F"/" '{print $NF}'`
	echo "Usage: $CMD <man page file name> [1 | 0]"
	echo "       1 - stands for INSTALL"
	echo "       0 - stands for UNINSTALL"
	echo
	exit 1
fi

MAN_FILE=$1
OPTION=$2

#The OPTION contains 0%postun during the LINUX RPM uninstallation time.
#The below fix will take ONLY the first char from the OPTION string
OPTION=`echo $OPTION | cut -f1 -d"%"`
# Get only the file name from the full path. Eg. file => /opt/tivoli/guid/tivguid.8 then FLNAME would be 'tivguid.8' and FILE would be 'tivguid'
FLNAME=`echo $MAN_FILE | awk -F"/" '{print $NF}'`
FILE=`echo $FLNAME | cut -d"." -f1`

# Get the section of the man page file Eg. man page file => tivguid.8 then SEC would be 8
SEC=`echo $MAN_FILE | awk -F"." '{print $NF}'`

if [ $OPTION -eq $INSTALL ]; then
	if [ ! -e ${MAN_FILE} ]; then
	        echo "File ${MAN_FILE} doesn't exist."
	        echo
	        exit 2
	fi
fi

if [ -d /usr/man/man${SEC} ]; then
	MAN_PAGE_LOC=/usr/man/man${SEC}
elif [ -d /usr/share/man/man${SEC} ]; then
	MAN_PAGE_LOC=/usr/share/man/man${SEC}
else
	echo "Couldn't find a man directory like 'man${SEC}'. Is the section '${SEC}' a valid one? If yes, all you'll need to do is"
	echo "create, or have someone else create, the directory \"/usr/man/man${SEC}\" and put ${MAN_FILE} file in there!"
	echo
	echo "Example:"
	echo "mkdir /usr/man/man${SEC}"
	echo "mv ${MAN_FILE} /usr/man/man${SEC}"
	echo
	exit 2
fi


#Install/Uninstall the man page
install_uninstall()
{
	if [ $OPTION -eq $INSTALL ]; then
		cp ${MAN_FILE} ${MAN_PAGE_LOC} || checkError $?  "ERROR! Check for the permissions of `pwd`/${MAN_FILE} as well as ${MAN_PAGE_LOC}."
		chown bin ${MAN_PAGE_LOC}/${FLNAME} || checkError $?  "ERROR! Couldn't chown the man page! Exiting..."
		chgrp bin ${MAN_PAGE_LOC}/${FLNAME} || checkError $?  "ERROR! Couldn't chgrp the man page! Exiting..."
		chmod 444 ${MAN_PAGE_LOC}/${FLNAME} || checkError $?  "ERROR! Couldn't chmod the man page! Exiting..."
		export MANPATH=$MANPATH:${MAN_PAGE_LOC}/../		# Updating the MANPATH variable to point to the proper man location
		echo "Success! The man page '${FLNAME}' got installed to ${MAN_PAGE_LOC}."
		echo "Now you can type \"man $FILE\" and hit return to see the man page!"
	else
		rm ${MAN_PAGE_LOC}/${FLNAME} || checkError $? "ERROR! Couldn't uninstall the man page!"
		rm -f /usr/man/cat${SEC}/${FLNAME}				# If cat${SEC} exists, delete from there too. If not, no issues. 
		rm -f /usr/share/man/cat${SEC}/${FLNAME}   		#       So no need of checking the error status here.
		echo "Success! Uninstalled the man page for '${FILE}'"
	fi
}

install_uninstall
echo
exit 0
